From: Stephen Rothwell <sfr@canb•auug.org.au>
To: Andi Kleen <andi@firstfloor•org>
Cc: linux-next@vger•kernel.org, linux-kernel@vger•kernel.org,
Wu Fengguang <fengguang.wu@intel•com>,
Hugh Dickins <hugh.dickins@tiscali•co.uk>,
Andrew Morton <akpm@linux-foundation•org>
Subject: linux-next: manual merge of the hwpoison tree with Linus' tree
Date: Wed, 16 Dec 2009 16:21:03 +1100 [thread overview]
Message-ID: <20091216162103.c423880d.sfr@canb.auug.org.au> (raw)
Hi Andi,
Today's linux-next merge of the hwpoison tree got a conflict in
mm/memcontrol.c between commit 407f9c8b0889ced1dbe2f9157e4e60c61329d5c9
("ksm: mem cgroup charge swapin copy") from Linus' tree and commit
eacbcea706766709f5c3bbbca208c04558a8d72f ("memcg: rename and export
try_get_mem_cgroup_from_page()") from the hwpoison tree.
Just context changes. I fixed it up (see below) and can carry the fix
for a while.
--
Cheers,
Stephen Rothwell sfr@canb•auug.org.au
diff --cc mm/memcontrol.c
index e0c2066,4e51af7..0000000
--- a/mm/memcontrol.c
+++ b/mm/memcontrol.c
@@@ -1737,13 -1739,12 +1739,13 @@@ int mem_cgroup_try_charge_swapin(struc
goto charge_cur_mm;
/*
* A racing thread's fault, or swapoff, may have already updated
* the pte, and even removed page from swap cache: return success
* to go on to do_swap_page()'s pte_same() test, which should fail.
*/
if (!PageSwapCache(page))
- return 0;
+ goto charge_cur_mm;
- mem = try_get_mem_cgroup_from_swapcache(page);
+ mem = try_get_mem_cgroup_from_page(page);
if (!mem)
goto charge_cur_mm;
*ptr = mem;
next reply other threads:[~2009-12-16 5:21 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-12-16 5:21 Stephen Rothwell [this message]
-- strict thread matches above, loose matches on Subject: below --
2010-10-08 3:40 linux-next: manual merge of the hwpoison tree with Linus' tree Stephen Rothwell
2010-10-08 6:11 ` Andi Kleen
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20091216162103.c423880d.sfr@canb.auug.org.au \
--to=sfr@canb$(echo .)auug.org.au \
--cc=akpm@linux-foundation$(echo .)org \
--cc=andi@firstfloor$(echo .)org \
--cc=fengguang.wu@intel$(echo .)com \
--cc=hugh.dickins@tiscali$(echo .)co.uk \
--cc=linux-kernel@vger$(echo .)kernel.org \
--cc=linux-next@vger$(echo .)kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
@@@ -1737,13 -1739,12 +1739,13 @@@ int mem_cgroup_try_charge_swapin(struc
/*
* A racing thread's fault, or swapoff, may have already updated
- * the pte, and even removed page from swap cache: return success
- * to go on to do_swap_page()'s pte_same() test, which should fail.
+ * the pte, and even removed page from swap cache: in those cases
+ * do_swap_page()'s pte_same() test will fail; but there's also a
+ * KSM case which does need to charge the page.
*/
if (!PageSwapCache(page))
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox